@@ -5,7 +5,7 @@ use English qw< -no_match_vars >;
 use 5.010;
 use File::Path qw< make_path >;
 use File::Basename qw< dirname >;
-our $VERSION = '0.721'; # TRIAL
+our $VERSION = '0.721001'; # TRIAL
 
 use Log::Log4perl::Tiny qw< :easy :dead_if_first >;
 use Mo qw< default >;
@@ -134,12 +134,15 @@ sub print {
       # get filehandle if needed
       $fh ||= $self->open();
 
+      # print interlude if we have previous records, increase count
+      $self->_print($fh, $interlude, $track)
+        if $track->{records};
+
       # print record
       $self->_print($fh, $record, $track);
 
-      # print interlude if we have previous records, increase count
-      $self->_print($fh, $interlude, $track)
-        if $track->{records}++;
+      # increment number of records, for next print
+      $track->{records}++;
 
       # do checks if activated
       $fh = $self->close($fh, $track)
